import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = (data,x_axis,y_axis) => {
  svg.selectAll("*").remove();
  const title = `Iris`;
  
  const xValue = d => d[x_axis];
  const xAxisLabel = `${x_axis}`;
  
  const yValue = d => d[y_axis];
  console.log(data);
  const circleRadius = 10;
  
  const yAxisLabel = `${y_axis}`;
  
  const margin = { top: 55, right: 40, bottom: 150, left: 100 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -60)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  g.selectAll('circle').data(data)
    .enter().append('circle')
  		.attr('class', d => d.class )
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius);
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -20)
      .text(title);
  g.append('text')
      .attr('class', 'Iris-setosa')
      .attr('y', 400)
  		.attr('x',-80)
      .text('setosa:blue');
  g.append('text')
      .attr('class', 'Iris-versicolor')
      .attr('y', 375)
  		.attr('x',-80)
      .text('versicolor:yellow');
  g.append('text')
      .attr('class', 'Iris-virginica')
      .attr('y', 350)
  		.attr('x',-80)
      .text('virginica:green');
};


csv('iris.csv')
  .then(data => {
    data.forEach(d => {
      d['sepal length'] = +d['sepal length'];
      d['sepal width'] = +d['sepal width'];
      d['petal length'] = +d['petal length'];
      d['petal width'] = +d['petal width'];
      if (d['class'] == null){
        d['sepal length'] = null;
      	d['sepal width'] = null;
      	d['petal length'] = null;
      	d['petal width'] = null;
      }
    });
  
  	render(data,'sepal length','sepal width');
  	const x_selection = document.querySelector('.x_axis');
    x_selection.addEventListener('change', (event) => {
    	let x_axis =  `${event.target.value}`;
      render(data,x_axis,y_selection.value);
    });
  	const y_selection = document.querySelector('.y_axis');
    y_selection.addEventListener('change', (event) => {
    	let y_axis =  `${event.target.value}`;
      render(data,x_selection.value,y_axis);
    });
  });